@@ -5,7 +5,7 @@ class Transformer(object):
         self.slug = slug
 
     def __repr__(self):
-        return "{x.__class__.__name__}('{x.name}', '{x.slug}')".format(x=self)
+        return u"{x.__class__.__name__}('{x.name}', '{x.slug}')".format(x=self)
 
     def __str__(self):
         return self.name
